==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DepozytPSwWplPozycja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DepozytPSwWplPozycja extends GenericDPSObject {
    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.DP_KONTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dpKontoId;

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieWplataId;

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.M_OPERACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mOperacjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.DP_KONTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDpKontoId() {
        return dpKontoId;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.DP_KONTO_ID
     *
     * @param dpKontoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDpKontoId(Long dpKontoId) {
        this.dpKontoId = dpKontoId;
    }

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.SWIADCZENIE_WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieWplataId() {
        return swiadczenieWplataId;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @param swiadczenieWplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieWplataId(Long swiadczenieWplataId) {
        this.swiadczenieWplataId = swiadczenieWplataId;
    }

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.M_OPERACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getmOperacjaId() {
        return mOperacjaId;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.M_OPERACJA_ID
     *
     * @param mOperacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setmOperacjaId(Long mOperacjaId) {
        this.mOperacjaId = mOperacjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPSwWplPozycja other = (DepozytPSwWplPozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpKontoId() == null ? other.getDpKontoId() == null : this.getDpKontoId().equals(other.getDpKontoId()))
            && (this.getSwiadczenieWplataId() == null ? other.getSwiadczenieWplataId() == null : this.getSwiadczenieWplataId().equals(other.getSwiadczenieWplataId()))
            && (this.getmOperacjaId() == null ? other.getmOperacjaId() == null : this.getmOperacjaId().equals(other.getmOperacjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpKontoId() == null) ? 0 : getDpKontoId().hashCode());
        result = prime * result + ((getSwiadczenieWplataId() == null) ? 0 : getSwiadczenieWplataId().hashCode());
        result = prime * result + ((getmOperacjaId() == null) ? 0 : getmOperacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpKontoId=").append(dpKontoId);
        sb.append(", swiadczenieWplataId=").append(swiadczenieWplataId);
        sb.append(", mOperacjaId=").append(mOperacjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DepozytPSwWplPozycja.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DepozytPSwWplPozycja extends GenericDPSObject {
    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.DP_KONTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dpKontoId;

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieWplataId;

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.M_OPERACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mOperacjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.DP_KONTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDpKontoId() {
        return dpKontoId;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.DP_KONTO_ID
     *
     * @param dpKontoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDpKontoId(Long dpKontoId) {
        this.dpKontoId = dpKontoId;
    }

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.SWIADCZENIE_WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieWplataId() {
        return swiadczenieWplataId;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.SWIADCZENIE_WPLATA_ID
     *
     * @param swiadczenieWplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieWplataId(Long swiadczenieWplataId) {
        this.swiadczenieWplataId = swiadczenieWplataId;
    }

    /**
     * @return DEPOZYT_P_SW_WPL_POZYCJA.M_OPERACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getmOperacjaId() {
        return mOperacjaId;
    }

    /**
     * DEPOZYT_P_SW_WPL_POZYCJA.M_OPERACJA_ID
     *
     * @param mOperacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setmOperacjaId(Long mOperacjaId) {
        this.mOperacjaId = mOperacjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPSwWplPozycja other = (DepozytPSwWplPozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDpKontoId() == null ? other.getDpKontoId() == null : this.getDpKontoId().equals(other.getDpKontoId()))
            && (this.getSwiadczenieWplataId() == null ? other.getSwiadczenieWplataId() == null : this.getSwiadczenieWplataId().equals(other.getSwiadczenieWplataId()))
            && (this.getmOperacjaId() == null ? other.getmOperacjaId() == null : this.getmOperacjaId().equals(other.getmOperacjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDpKontoId() == null) ? 0 : getDpKontoId().hashCode());
        result = prime * result + ((getSwiadczenieWplataId() == null) ? 0 : getSwiadczenieWplataId().hashCode());
        result = prime * result + ((getmOperacjaId() == null) ? 0 : getmOperacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dpKontoId=").append(dpKontoId);
        sb.append(", swiadczenieWplataId=").append(swiadczenieWplataId);
        sb.append(", mOperacjaId=").append(mOperacjaId);
        sb.append("]");
        return sb.toString();
    }
}
